

from django.shortcuts import render,redirect
from django.http import HttpResponse
from users.forms import UserRegistrationForm, UserUpdateForm, ProfileUpdateForm
from django.contrib.auth.models import User
from django.contrib import messages

from django.contrib.auth import logout
from django.contrib.auth.decorators import login_required


def register_view(request):
    if request.method == "POST":
        form = UserRegistrationForm(request.POST)
        if form.is_valid():
            form.save()
            username = form.cleaned_data.get('username')
            messages.success(request, f'Account created for {username} successfully!')
            return redirect('home_page')
        else:
            username = form.cleaned_data.get('username')
            messages.warning(request, f'Account not created for {username} successfully!')
            return redirect('register_page')
    else:
        form = UserRegistrationForm()
        context = {
            'form': form
        }
        return render(request, 'users/register.html', context)


def logout_view(request):
    logout(request)
    return redirect('login_page')


@login_required(login_url='login_page')
def profile(request):
    if request.method == 'POST':
        user_form = UserUpdateForm(request.POST, instance=request.user)
        profile_form = ProfileUpdateForm(request.POST, request.FILES, instance=request.user.profile)
        if user_form.is_valid() and profile_form.is_valid():
            user_form.save()
            profile_form.save()
            messages.success(request, f'Your account has been updated!')
            return redirect('profile_page')
    else:
        user_form = UserUpdateForm(instance=request.user)
        profile_form = ProfileUpdateForm(instance=request.user.profile)
        context = {
            "user_form" : user_form,
            "profile_form" : profile_form,
        }
        return render(request, 'users/profile.html', context)



'''
@login_required(login_url='login_page')
def profile(request):
    context = {
        "user" : request.user
    }
    return render(request, 'users/profile.html', context)
'''


















